import { PageDataChange, PageModeChange } from "../control/events";
import { Relationship } from "../svi-datahub";
import { QueryMode } from "../svi-sand";
import { ControlContainer } from "../object/object-api";
import { PageModel, PageModelObjectData } from "../page-model/page-model-api";
import { SearchObject, SearchQuery } from "../search/client/client-search-api";
import { HandleType, MinMaxDates, TimeSliderContextMenuHideOptions, TimeSliderEventDates, TimeSliderRange, TimeSliderRangeChangedEvent } from "../time-slider";
export interface SearchAndSelectWithPreviewInputBindings {
    initialQuery?: string;
    additionalModes?: QueryMode[];
    objectTypeFilter?: string[];
}
export interface SearchAndSelectWithPreviewBindings extends SearchAndSelectWithPreviewInputBindings {
    onSearchItemSelected: (selectedItem: SearchObject | null) => void;
    onSearchItemDoubleClicked?: (selectedItem: SearchObject) => void;
}
export interface PageViewerApi {
    save: () => Promise<void>;
    isDirty: () => boolean;
    isValid: () => Promise<boolean>;
}
export interface PageBindings {
    docId?: string;
    docType?: string;
    eventName?: string;
    templateUuid?: string;
    showToolbar?: boolean;
    tempCreateId?: string;
    containerClass?: string;
    fitToContainerHeight?: boolean;
    pageClass?: string;
    enableSheets?: string;
    pageModel?: PageModel;
    staticDocumentData?: Record<string, any>;
    initialCreateData?: Record<string, any>;
    setApi?: (api: PageViewerApi) => void;
    mainTab?: string;
    onDirty?: (isDirty: boolean) => void;
    onChange?: (change: PageDataChange | PageModeChange) => void;
}
export interface PagePreviewBindings {
    templateUuid: string;
}
export interface ControlCollectionBindings {
    controlContainer?: ControlContainer;
    pageModel?: PageModel;
    root?: boolean;
}
export interface RelationshipDetailsBindings {
    targetObjectTypeName: string;
    targetObjectTypeLabel: string;
    parentObjectTypeName: string;
    parentObjectTypeLabel: string;
    linkReasons: Relationship[];
    selectedItem?: {
        id: string;
        type: string;
    };
    newPageModel?: {
        model: PageModelObjectData;
    };
    onLinkReasonSelected: (linkReason: Relationship) => void;
    relationshipValues?: Record<string, any>;
    initialCreateData?: Record<string, any>;
    setApi?: (api: PageViewerApi) => void;
    onRelatedPageChange?: (change: PageDataChange | PageModeChange) => void;
    onRelationshipValuesChange?: (current: Record<string, any>, previous?: Record<string, any>) => void;
}
export interface SearchInputInputBindings {
    entityName: string;
    queryBuilderId?: string;
    showQueryBuilder?: boolean;
    queryText?: string;
    autoFocus?: boolean;
    queryBuilderOkButtonLabel?: string;
    queryModel?: QueryBuilderModel;
    performSearch?: boolean;
}
export interface QueryBuilderModel {
    manualQueryString?: string;
    model: QueryBuilderEntityModel[];
}
export interface QueryBuilderEntityModel {
    entity: string;
    queries: QueryBuilderItem[];
    singleChildSearch?: boolean;
}
export interface QueryBuilderItem {
    booleanValue?: boolean | string;
    boost?: number;
    dateTimeValue?: string | Date;
    dateValue?: string | Date;
    exclude?: boolean;
    field?: string;
    fromDateTimeValue?: string | Date;
    fromDateValue?: string | Date;
    fromNumericValue?: number;
    numericValue?: number;
    operator?: string;
    phonetic?: boolean;
    previousField?: string;
    proximity?: number;
    rangeValidationError?: boolean;
    referenceValue?: string;
    relationshipField?: boolean;
    relationshipTypeValue?: string;
    relativeDateDatetimeNumericValue?: number;
    relativeDateDatetimeUnitsValue?: string;
    stringValidationError?: boolean;
    synonym?: boolean;
    textValue?: string;
    toDateTimeValue?: string | Date;
    toDateValue?: string | Date;
    toNumericValue?: number;
    userGroupValue?: Array<{
        id: string;
        type: string;
    }>;
}
export interface SearchInputBindings extends SearchInputInputBindings {
    onSearch?: (model: SearchQuery) => void;
    onValueChange?: (val: string) => void;
}
export interface TimeSliderInputBindings {
    timeSliderId: string;
    timeSliderDates: TimeSliderEventDates;
    viewRange: TimeSliderRange;
    handleType?: HandleType;
    isReadOnly?: boolean;
    sliderWidth?: number;
    disableSwitchHandleType?: boolean;
    contextMenuHideOptions: TimeSliderContextMenuHideOptions;
    minMaxDates?: MinMaxDates;
}
export interface TimeSliderBindings extends TimeSliderInputBindings {
    rangeChangeEvent?: (rangeChangedEvent: TimeSliderRangeChangedEvent) => void;
    handleTypeChange?: (handleType: HandleType) => void;
    onLoad?: () => void;
    close?: () => void;
}
export type SviComponentBindings = ControlCollectionBindings | RelationshipDetailsBindings | SearchInputBindings | PageBindings | SearchAndSelectWithPreviewBindings | TimeSliderBindings;
